@@ -11,9 +11,8 @@ from mkdocs.exceptions import ConfigurationError
 
 from mkdocs_table_reader_plugin.safe_eval import parse_argkwarg
 
-
 def get_keywords(func):
-    return [p.name for p in signature(func).parameters.values() if p.kind == p.POSITIONAL_OR_KEYWORD]
+    return [p.name for p in signature(func).parameters.values() if p.kind == p.POSITIONAL_OR_KEYWORD or p.kind == p.KEYWORD_ONLY]
 
 def kwargs_in_func(keywordargs, func):
     return dict({(k,v) for k, v in keywordargs.items() if k in get_keywords(func)})
